pub enum Metadata {
Cassandra(CassandraMetadata),
Valkey,
Kafka,
OpenSearch,
}Variants
Implementations
Sourceimpl Metadata
impl Metadata
Sourcepub fn to_error_response(&self, error: String) -> Result<Message>
pub fn to_error_response(&self, error: String) -> Result<Message>
Returns an error response with the provided error message.
If the metadata is from a request: the returned Message is a valid response to self
If the metadata is from a response: the returned Message is a valid replacement of self