pub struct Loopback {}Trait Implementations
Sourceimpl Transform for Loopback
impl Transform for Loopback
Sourcefn get_name(&self) -> &'static str
fn get_name(&self) -> &'static str
Name of the transform used in logs and displayed to the user
Sourcefn transform<'shorter, 'longer, 'life0, 'async_trait>(
&'life0 mut self,
chain_state: &'shorter mut ChainState<'longer>,
) -> Pin<Box<dyn Future<Output = Result<Messages>> + Send + 'async_trait>>where
Self: 'async_trait,
'shorter: 'async_trait,
'longer: 'async_trait + 'shorter,
'life0: 'async_trait,
fn transform<'shorter, 'longer, 'life0, 'async_trait>(
&'life0 mut self,
chain_state: &'shorter mut ChainState<'longer>,
) -> Pin<Box<dyn Future<Output = Result<Messages>> + Send + 'async_trait>>where
Self: 'async_trait,
'shorter: 'async_trait,
'longer: 'async_trait + 'shorter,
'life0: 'async_trait,
In order to implement your transform you can modify the messages: Read more
Sourceimpl TransformBuilder for Loopback
impl TransformBuilder for Loopback
Sourcefn build(
&self,
_transform_context: TransformContextBuilder,
) -> Box<dyn Transform>
fn build( &self, _transform_context: TransformContextBuilder, ) -> Box<dyn Transform>
Builds a single instance of the transform.
Shotover will create a new transform instance by calling this method for every time this transform is configured in the
topology.yaml.Sourcefn get_name(&self) -> &'static str
fn get_name(&self) -> &'static str
Name of the transform used in logs and displayed to the user
fn is_terminating(&self) -> bool